aboutsummaryrefslogtreecommitdiff
path: root/backends/platform/symbian/src/SymbianOS.h
diff options
context:
space:
mode:
authorMax Horn2007-03-17 19:02:05 +0000
committerMax Horn2007-03-17 19:02:05 +0000
commited54ea9155961d8ca5d5fb3c7777fc57a29f2751 (patch)
tree467b926af11cd4129ba003d04ba01de044c7a6df /backends/platform/symbian/src/SymbianOS.h
parentf272d1957084098c5b53975ad3501074f6971af8 (diff)
downloadscummvm-rg350-ed54ea9155961d8ca5d5fb3c7777fc57a29f2751.tar.gz
scummvm-rg350-ed54ea9155961d8ca5d5fb3c7777fc57a29f2751.tar.bz2
scummvm-rg350-ed54ea9155961d8ca5d5fb3c7777fc57a29f2751.zip
Moved Event/EventType/keyboard enum from common/system.h (part of class OSystem) to common/events.h (part of namespace Common). Porters may have to make minor changes to their backends to get them to compile again
svn-id: r26180
Diffstat (limited to 'backends/platform/symbian/src/SymbianOS.h')
-rw-r--r--backends/platform/symbian/src/SymbianOS.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/backends/platform/symbian/src/SymbianOS.h b/backends/platform/symbian/src/SymbianOS.h
index bb3a992891..80278af58c 100644
--- a/backends/platform/symbian/src/SymbianOS.h
+++ b/backends/platform/symbian/src/SymbianOS.h
@@ -104,9 +104,9 @@ protected:
// This is an implementation by the remapKey function
// @param SDL_Event to remap
// @param ScumVM event to modify if special result is requested
// @return true if Event has a valid return status
//
- bool remapKey(SDL_Event &ev, Event &event);
+ bool remapKey(SDL_Event &ev, Common::Event &event);
void setWindowCaption(const char *caption);
@@ -104,9 +104,9 @@ protected:
// @param SDL_Event to remap
// @param ScumVM event to modify if special result is requested
- // @return true if Event has a valid return status
+ // @return true if Common::Event has a valid return status
//